@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -25,7 +25,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <locale.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 #include <dbus/dbus-glib.h>
 
 #include "egg-debug.h"
@@ -45,12 +45,9 @@ main (int argc, char *argv[])
 	DBusGProxy *proxy = NULL;
 	GError *error = NULL;
 	gboolean ret;
-	gboolean verbose = FALSE;
 	gchar **files = NULL;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-		  _("Show extra debugging information"), NULL },
 		{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &files,
 		/* TRANSLATORS: command line option: a list of catalogs to install */
 		  _("Catalogs files to install"), NULL },
@@ -66,18 +63,18 @@ main (int argc, char *argv[])
 	if (! g_thread_supported ())
 		g_thread_init (NULL);
 	g_type_init ();
+	gtk_init (&argc, &argv);
 
 	/* TRANSLATORS: program name: application to install a catalog of software */
 	g_set_application_name (_("Catalog Installer"));
 	context = g_option_context_new ("gpk-install-catalog");
 	g_option_context_set_summary (context, _("Catalog Installer"));
 	g_option_context_add_main_entries (context, options, NULL);
+	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
-	egg_debug_init (verbose);
-	gtk_init (&argc, &argv);
-
 	/* are we running privileged */
 	ret = gpk_check_privileged_user (_("Catalog installer"), TRUE);
 	if (!ret)
@@ -114,7 +111,7 @@ main (int argc, char *argv[])
 	ret = dbus_g_proxy_call (proxy, "InstallCatalogs", &error,
 				 G_TYPE_UINT, 0, /* xid */
 				 G_TYPE_STRV, files, /* data */
-				 G_TYPE_STRING, "", /* interaction */
+				 G_TYPE_STRING, "hide-finished,hide-warnings", /* interaction */
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
